@@ -1,4 +1,4 @@
-import pymysql, psycopg2, psycopg2.extras, datetime, socket, configparser
+import pymysql, psycopg2, datetime, socket, configparser
 
 host_ = socket.gethostbyname(socket.gethostname())
 port_ = 80 # Default XAMPP Apache server port.
@@ -58,7 +58,7 @@ def get_connection_object(conn):
     # PostgreSQL
     if (mode_ == "PostgreSQL"):
         if curs_ == "DICTIONARY":
-            return conn.cursor(cursor_factory=psycopg2.extras.DictCursor)
+            return conn.cursor(cursor_factory=DictCursor)
         else:
             return conn.cursor()
     # MySQL (by Default)
